<?php
/**
 * Dustland Express functions and definitions
 *
 * @package dustlandexpress
 */
define( 'DUSTLANDEXPRESS_THEME_VERSION' , '1.2.3' );



if ( ! function_exists( 'dustlandexpress_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function dustlandexpress_theme_setup() {
	
	/**
	 * Set the content width based on the theme's design and stylesheet.
	 */
	global $content_width;
	if ( ! isset( $content_width ) ) {
		$content_width = 640; /* pixels */
	}

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Dustland Express, use a find and replace
	 * to change 'dustlandexpress' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'dustlandexpress', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
    if ( function_exists( 'add_image_size' ) ) {
        add_image_size( 'blog_img_side', 352, 230, true );
        add_image_size( 'blog_img_top', 1100, 440, true );
    }

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'dustlandexpress' ),
        'footer-bar' => __( 'Footer Bar Menu', 'dustlandexpress' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
	
	// The custom header is used for the logo
	add_theme_support( 'custom-header', array(
        'default-image' => '',
		'width'         => 280,
		'height'        => 91,
		'flex-width'    => true,
		'flex-height'   => true,
		'header-text'   => false,
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'dustlandexpress_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
    
    add_theme_support( 'title-tag' );
	
	add_theme_support( 'woocommerce' );
}
endif; // dustlandexpress_theme_setup
add_action( 'after_setup_theme', 'dustlandexpress_theme_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function dustlandexpress_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'dustlandexpress' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>'
	) );
	
	register_sidebar(array(
		'name' => __( 'Dustland Express Footer', 'dustlandexpress' ),
		'id' => 'dustlandexpress-site-footer',
        'description' => __( 'The footer will divide into however many widgets are put here.', 'dustlandexpress' )
	));
}
add_action( 'widgets_init', 'dustlandexpress_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function dustlandexpress_theme_scripts() {
    wp_enqueue_style( 'dustlandexpress-google-body-font-default', '//fonts.googleapis.com/css?family=Ubuntu:300,400,500,700,300italic,400italic,500italic,700italic', array(), DUSTLANDEXPRESS_THEME_VERSION );
    wp_enqueue_style( 'dustlandexpress-google-heading-font-default', '//fonts.googleapis.com/css?family=Roboto:500,400italic,700italic,300,700,500italic,300italic,400', array(), DUSTLANDEXPRESS_THEME_VERSION );
    
	wp_enqueue_style( 'dustlandexpress-font-awesome', get_template_directory_uri().'/includes/font-awesome/css/font-awesome.css', array(), '4.2.0' );
	wp_enqueue_style( 'dustlandexpress-style', get_stylesheet_uri(), array(), DUSTLANDEXPRESS_THEME_VERSION );
    wp_enqueue_style( 'dustlandexpress-woocommerce-style', get_template_directory_uri().'/templates/css/dustlandexpress-woocommerce-style.css', array(), DUSTLANDEXPRESS_THEME_VERSION );
	
	if ( get_theme_mod( 'kra-header-layout', false ) == 'kra-header-layout-centered' ) {
		wp_enqueue_style( 'dustlandexpress-header-centered-style', get_template_directory_uri().'/templates/css/dustlandexpress-header-centered.css', array(), DUSTLANDEXPRESS_THEME_VERSION );
	} else {
		wp_enqueue_style( 'dustlandexpress-header-standard-style', get_template_directory_uri().'/templates/css/dustlandexpress-header-standard.css', array(), DUSTLANDEXPRESS_THEME_VERSION );
	}

	wp_enqueue_script( 'dustlandexpress-navigation', get_template_directory_uri() . '/js/navigation.js', array(), DUSTLANDEXPRESS_THEME_VERSION, true );
	wp_enqueue_script( 'dustlandexpress-caroufredSel', get_template_directory_uri() . '/js/jquery.carouFredSel-6.2.1-packed.js', array('jquery'), DUSTLANDEXPRESS_THEME_VERSION, true );
	
	if ( get_theme_mod( 'kra-sticky-header', false ) ) {
		wp_enqueue_script( 'dustlandexpress-waypoints', get_template_directory_uri() . '/js/waypoints.min.js', array('jquery'), DUSTLANDEXPRESS_THEME_VERSION, true );
	    wp_enqueue_script( 'dustlandexpress-waypoints-sticky', get_template_directory_uri() . '/js/waypoints-sticky.min.js', array('jquery'), DUSTLANDEXPRESS_THEME_VERSION, true );
	}
	
	wp_enqueue_script( 'dustlandexpress-customjs', get_template_directory_uri() . '/js/custom.js', array('jquery'), DUSTLANDEXPRESS_THEME_VERSION, true );

	wp_enqueue_script( 'dustlandexpress-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), DUSTLANDEXPRESS_THEME_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'dustlandexpress_theme_scripts' );

/**
 * Print Dustland Express styling settings.
 */
function dustlandexpress_print_styles(){
    $custom_css = '';
    if ( get_theme_mod( 'kra-custom-css', false ) ) {
        $custom_css = get_theme_mod( 'kra-custom-css' );
    } ?>
    <style type="text/css" media="screen">
        <?php echo htmlspecialchars_decode( $custom_css ); ?>
    </style>
<?php
}
add_action('wp_head', 'dustlandexpress_print_styles', 11);

// Add the favicon to the header if set
function dustlandexpress_site_favicon() {
    if ( get_theme_mod( 'kra-header-favicon', false ) ) :
        echo '<link rel="icon" href="' . esc_url( get_theme_mod( 'kra-header-favicon' ) ) . '">';
    endif;
}
add_action('wp_head', 'dustlandexpress_site_favicon');

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/includes/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/includes/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/includes/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/includes/inc/jetpack.php';

// Helper library for the theme customizer.
require get_template_directory() . '/customizer/customizer-library/customizer-library.php';

// Define options for the theme customizer.
require get_template_directory() . '/customizer/customizer-options.php';

// Output inline styles based on theme customizer selections.
require get_template_directory() . '/customizer/styles.php';

// Additional filters and actions based on theme customizer selections.
require get_template_directory() . '/customizer/mods.php';

/**
 * Enqueue Dustland Express custom customizer styling.
 */
function dustlandexpress_load_customizer_script() {
    wp_enqueue_script( 'dustlandexpress-customizer-js', get_template_directory_uri() . '/customizer/customizer-library/js/customizer-custom.js', array('jquery'), DUSTLANDEXPRESS_THEME_VERSION, true );
    
    wp_enqueue_style( 'dustlandexpress-customizer-css', get_template_directory_uri() . '/customizer/customizer-library/css/customizer.css' );
}    
add_action( 'customize_controls_enqueue_scripts', 'dustlandexpress_load_customizer_script' );

/* Display the recommended plugins notice that can be dismissed */
add_action('admin_notices', 'dustlandexpress_recommended_plugin_notice');

function dustlandexpress_recommended_plugin_notice() {
    global $pagenow;
    global $current_user;
    
    $user_id = $current_user->ID;
    
    /* If on plugins page, check that the user hasn't already clicked to ignore the message */
    if ( $pagenow == 'plugins.php' ) {
	    if ( ! get_user_meta( $user_id, 'dustlandexpress_recommended_plugin_ignore_notice' ) ) {
	        echo '<div class="updated"><p>';
            printf( __( '<p>Install the plugins we at <a href="http://www.kairaweb.com/" target="_blank">Kaira</a> recommended | <a href="%1$s">Hide Notice</a></p>', 'dustlandexpress' ), '?dustlandexpress_recommended_plugin_nag_ignore=0' ); ?>
            <a href="<?php echo admin_url('plugin-install.php?tab=favorites&user=kaira'); ?>"><?php printf( __( 'WooCommerce', 'dustlandexpress' ), 'dustlandexpress' ); ?></a><br />
            <a href="<?php echo admin_url('plugin-install.php?tab=favorites&user=kaira'); ?>"><?php printf( __( 'SiteOrigin\'s Page Builder', 'dustlandexpress' ), 'dustlandexpress' ); ?></a><br />
            <a href="<?php echo admin_url('plugin-install.php?tab=favorites&user=kaira'); ?>"><?php printf( __( 'Meta Slider', 'dustlandexpress' ), 'dustlandexpress' ); ?></a><br />
            <a href="<?php echo admin_url('plugin-install.php?tab=favorites&user=kaira'); ?>"><?php printf( __( 'Breadcrumb NavXT', 'dustlandexpress' ), 'dustlandexpress' ); ?></a>
            <?php
	        echo "</p></div>";
	    }
	}
}
add_action('admin_init', 'dustlandexpress_recommended_plugin_nag_ignore');

function dustlandexpress_recommended_plugin_nag_ignore() {
    global $current_user;
    $user_id = $current_user->ID;
        
    /* If user clicks to ignore the notice, add that to their user meta */
    if ( isset($_GET['dustlandexpress_recommended_plugin_nag_ignore']) && '0' == $_GET['dustlandexpress_recommended_plugin_nag_ignore'] ) {
        add_user_meta( $user_id, 'dustlandexpress_recommended_plugin_ignore_notice', 'true', true );
    }
}

// Create function to check if WooCommerce exists.
if ( ! function_exists( 'dustlandexpress_is_woocommerce_activated' ) ) :
    
function dustlandexpress_is_woocommerce_activated() {
    if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
}

endif; // dustlandexpress_is_woocommerce_activated

if ( dustlandexpress_is_woocommerce_activated() ) {
    require get_template_directory() . '/includes/inc/woocommerce-inc.php';
}

/**
 * Adjust is_home query if kra-blog-cats is set
 */
function dustlandexpress_set_blog_queries( $query ) {
    $blog_query_set = '';
    if ( get_theme_mod( 'kra-blog-cats', false ) ) {
        $blog_query_set = get_theme_mod( 'kra-blog-cats' );
    }
    
    if ( $blog_query_set ) {
        // do not alter the query on wp-admin pages and only alter it if it's the main query
        if ( !is_admin() && $query->is_main_query() ){
            if ( is_home() ){
                $query->set( 'cat', $blog_query_set );
            }
        }
    }
}
add_action( 'pre_get_posts', 'dustlandexpress_set_blog_queries' );

/**
 * Display the upgrade to Premium page & losd styles.
 *
 * @action admin_menu
 */
function dustlandexpress_premium_admin_menu() {
    global $dustlandexpress_upgrade_page;
    $dustlandexpress_upgrade_page = add_theme_page( __( 'Dustland Express Premium', 'dustlandexpress' ), __( 'Dustland Express Premium', 'dustlandexpress' ), 'edit_theme_options', 'premium_upgrade', 'dustlandexpress_upgrade_page_render' );
}

add_action( 'admin_menu', 'dustlandexpress_premium_admin_menu' );

/**
 * Render the theme upgrade page
 */
function dustlandexpress_upgrade_page_render() {
    locate_template( 'upgrade/kaira-upgrade-page.php', true, false );
}

/**
 * Enqueue Dustland Express admin stylesheet only on upgrade page.
 */
function dustlandexpress_load_admin_style($hook) {
    global $dustlandexpress_upgrade_page;
 
    if( $hook != $dustlandexpress_upgrade_page ) 
        return;
    
    wp_enqueue_style( 'dustlandexpress-upgrade-css', get_template_directory_uri() . '/upgrade/css/kaira-admin.css' );
}    
add_action( 'admin_enqueue_scripts', 'dustlandexpress_load_admin_style' );

/**
 * Remove slider category from the sidebar categories widget
 */
function dustlandexpress_exclude_slider_categories_widget( $args ) {
	$exclude = ''; // ID's of the categories to exclude
	if ( get_theme_mod( 'kra-slider-cats', false ) ) {
        $exclude = get_theme_mod( 'kra-slider-cats' );
    }
	$args['exclude'] = $exclude;
	return $args;
}
add_filter( 'widget_categories_args', 'dustlandexpress_exclude_slider_categories_widget' );